Array (imandra-base.Imandra_prelude.Array)

### Arrays

Program mode only

A program-mode imperative array, that can be mutated

`include module type of struct include Caml.Array end`
`type !'a t = 'a array`
`val create : int -> 'a -> 'a array`
`val create_float : int -> float array`
`val make_float : int -> float array`
`val make_matrix : int -> int -> 'a -> 'a array array`
`val create_matrix : int -> int -> 'a -> 'a array array`
`val append : 'a array -> 'a array -> 'a array`
`val concat : 'a array list -> 'a array`
`val copy : 'a array -> 'a array`
`val to_list : 'a array -> 'a list`
`val of_list : 'a list -> 'a array`
`val iter : ( 'a -> unit ) -> 'a array -> unit`
`val map : ( 'a -> 'b ) -> 'a array -> 'b array`
`val fold_left : ( 'a -> 'b -> 'a ) -> 'a -> 'b array -> 'a`
`val fold_right : ( 'b -> 'a -> 'a ) -> 'b array -> 'a -> 'a`
`val iter2 : ( 'a -> 'b -> unit ) -> 'a array -> 'b array -> unit`
`val map2 : ( 'a -> 'b -> 'c ) -> 'a array -> 'b array -> 'c array`
`val for_all : ( 'a -> bool ) -> 'a array -> bool`
`val exists : ( 'a -> bool ) -> 'a array -> bool`
`val for_all2 : ( 'a -> 'b -> bool ) -> 'a array -> 'b array -> bool`
`val exists2 : ( 'a -> 'b -> bool ) -> 'a array -> 'b array -> bool`
`val mem : 'a -> 'a array -> bool`
`val memq : 'a -> 'a array -> bool`
`val sort : ( 'a -> 'a -> int ) -> 'a array -> unit`
`val stable_sort : ( 'a -> 'a -> int ) -> 'a array -> unit`
`val fast_sort : ( 'a -> 'a -> int ) -> 'a array -> unit`
`val to_seq : 'a array -> 'a Stdlib.Seq.t`
`val to_seqi : 'a array -> (int * 'a) Stdlib.Seq.t`
`val of_seq : 'a Stdlib.Seq.t -> 'a array`
`val unsafe_get : 'a array -> int -> 'a`
`val unsafe_set : 'a array -> int -> 'a -> unit`
`module Floatarray = Stdlib__array.Floatarray`
`val get : 'a array -> Z.t -> 'a`
`val set : 'a array -> Z.t -> 'a -> unit`
`val make : Z.t -> 'a -> 'a array`
`val init : Z.t -> ( Z.t -> 'a ) -> 'a array`
`val sub : 'a array -> Z.t -> Z.t -> 'a array`
`val length : 'a array -> Z.t`
`val mapi : ( Z.t -> 'a -> 'b ) -> 'a array -> 'b array`
`val iteri : ( Z.t -> 'a -> unit ) -> 'a array -> unit`
`val fill : 'a array -> Z.t -> Z.t -> 'a -> unit`
`val blit : 'a array -> Z.t -> 'a array -> Z.t -> Z.t -> unit`